@@ -60,9 +60,10 @@ target_column = 'target'
 
 ################################################################################################
 # categorical features
-# import seaborn as sns
-# df = sns.load_dataset("tips")
-# df.rename(columns={'tip': target_column}, inplace=True)
+import seaborn as sns
+
+df = sns.load_dataset("tips")
+df.rename(columns={'tip': target_column}, inplace=True)
 ################################################################################################
 
 ################################################################################################
@@ -83,12 +84,25 @@ target_column = 'target'
 
 
 ###############################################################################################
-df = pd.read_csv("chester/run_manual_chester/flipkart_product.csv", encoding="ISO-8859-1")
-df = df[['Review', 'Summary', 'Rate']]
-df['Rate'] = "category: " + df['Rate'].astype(str)
-df.rename(columns={'Rate': 'target'}, inplace=True)
-df.dropna(subset=['target'], inplace=True)
-df = df.sample(5000)
+# df = pd.read_csv("chester/run_manual_chester/flipkart_product.csv", encoding="ISO-8859-1")
+# df = df[['Review', 'Summary', 'Rate']]
+# df['Rate'] = "category: " + df['Rate'].astype(str)
+# df.rename(columns={'Rate': 'target'}, inplace=True)
+# df.dropna(subset=['target'], inplace=True)
+# df = df.sample(5000)
+###############################################################################################
+
+
+###############################################################################################
+df1 = pd.read_csv("chester/run_manual_chester/Bank_Personal_Loan_Modelling.csv")
+df = df1.copy(deep=False)
+df.rename(columns={'Personal Loan': 'target'}, inplace=True)
+
+feature_types = {'numeric':
+                     ['ID', 'Age', 'Experience', 'Income', 'Family',
+                      'CCAvg', 'Education', 'Mortgage', 'Securities Account',
+                      'CD Account', 'Online', 'CreditCard'], 'boolean': [],
+                 'text': [], 'categorical': ['Education'], 'time': []}
 
 
 ###############################################################################################
@@ -200,10 +214,11 @@ def load_ex5():
 #                               model_run=ModelRun(n_models=3),
 #                               is_post_model=True, is_model_weaknesses=True
 #                               )
-feature_types = {'numeric': [], 'boolean': [], 'text': ['Summary', 'Review'],
-                 'categorical': [], 'time': []}
+
 output_collector = run_madcat(
-    Data(df=df.sample(1000), target_column='target'),
+    Data(df=df, target_column='target'),
     model_run=ModelRun(n_models=3),
-    feature_types=feature_types
+    is_feature_stats=True,
+    feature_types=feature_types,
+    is_model_training=True, is_post_model=True, is_model_weaknesses=True
 )
